@@ -28,6 +28,8 @@ pub mod cloudiot_device;
 pub use self::cloudiot_device::CloudiotDevice;
 pub mod cloudiot_device_request;
 pub use self::cloudiot_device_request::CloudiotDeviceRequest;
+pub mod command_enum;
+pub use self::command_enum::CommandEnum;
 pub mod detail_response;
 pub use self::detail_response::DetailResponse;
 pub mod device;
@@ -44,10 +46,6 @@ pub mod device_info_request;
 pub use self::device_info_request::DeviceInfoRequest;
 pub mod device_request;
 pub use self::device_request::DeviceRequest;
-pub mod device_state;
-pub use self::device_state::DeviceState;
-pub mod device_state_command_enum;
-pub use self::device_state_command_enum::DeviceStateCommandEnum;
 pub mod email_auth_request;
 pub use self::email_auth_request::EmailAuthRequest;
 pub mod error_detail;
@@ -64,8 +62,6 @@ pub mod gcode_file;
 pub use self::gcode_file::GcodeFile;
 pub mod license;
 pub use self::license::License;
-pub mod license_credentials;
-pub use self::license_credentials::LicenseCredentials;
 pub mod license_request;
 pub use self::license_request::LicenseRequest;
 pub mod mobile_auth_request;
@@ -142,8 +138,6 @@ pub mod paginated_device_info_list;
 pub use self::paginated_device_info_list::PaginatedDeviceInfoList;
 pub mod paginated_device_list;
 pub use self::paginated_device_list::PaginatedDeviceList;
-pub mod paginated_device_state_list;
-pub use self::paginated_device_state_list::PaginatedDeviceStateList;
 pub mod paginated_experiment_device_config_list;
 pub use self::paginated_experiment_device_config_list::PaginatedExperimentDeviceConfigList;
 pub mod paginated_experiment_list;
@@ -172,6 +166,8 @@ pub mod paginated_remote_command_event_list;
 pub use self::paginated_remote_command_event_list::PaginatedRemoteCommandEventList;
 pub mod paginated_remote_control_command_list;
 pub use self::paginated_remote_control_command_list::PaginatedRemoteControlCommandList;
+pub mod paginated_system_task_list;
+pub use self::paginated_system_task_list::PaginatedSystemTaskList;
 pub mod paginated_telemetry_event_polymorphic_list;
 pub use self::paginated_telemetry_event_polymorphic_list::PaginatedTelemetryEventPolymorphicList;
 pub mod paginated_user_list;
@@ -250,14 +246,16 @@ pub mod remote_command_event_request;
 pub use self::remote_command_event_request::RemoteCommandEventRequest;
 pub mod remote_control_command;
 pub use self::remote_control_command::RemoteControlCommand;
-pub mod remote_control_command_command_enum;
-pub use self::remote_control_command_command_enum::RemoteControlCommandCommandEnum;
 pub mod remote_control_command_request;
 pub use self::remote_control_command_request::RemoteControlCommandRequest;
 pub mod software_enum;
 pub use self::software_enum::SoftwareEnum;
 pub mod status_enum;
 pub use self::status_enum::StatusEnum;
+pub mod system_task;
+pub use self::system_task::SystemTask;
+pub mod system_task_request;
+pub use self::system_task_request::SystemTaskRequest;
 pub mod telemetry_event;
 pub use self::telemetry_event::TelemetryEvent;
 pub mod telemetry_event_event_type_enum;
@@ -270,6 +268,8 @@ pub mod telemetry_event_request;
 pub use self::telemetry_event_request::TelemetryEventRequest;
 pub mod token_response;
 pub use self::token_response::TokenResponse;
+pub mod type_enum;
+pub use self::type_enum::TypeEnum;
 pub mod user;
 pub use self::user::User;
 pub mod user_request;
